#!/usr/bin/env node
'use strict';

var _stylelint = require('stylelint');

var _stylelint2 = _interopRequireDefault(_stylelint);

var _meow = require('meow');

var _meow2 = _interopRequireDefault(_meow);

var _boxen = require('boxen');

var _boxen2 = _interopRequireDefault(_boxen);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _cliTable = require('cli-table');

var _cliTable2 = _interopRequireDefault(_cliTable);

var _stylelintConfigWilco = require('stylelint-config-wilco');

var _stylelintConfigWilco2 = _interopRequireDefault(_stylelintConfigWilco);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorTemp = _chalk2.default.bold.red;

var wilco = function wilco(files) {
  return _stylelint2.default.lint({
    config: _stylelintConfigWilco2.default,
    files: files
  }).then(function (resultObject) {
    var r = resultObject.results;
    if (resultObject.errored === true) {
      for (var i = 0; i < r.length; i++) {
        var warnings = r[i].warnings;
        var table = new _cliTable2.default({
          head: [_chalk2.default.blue('Ln:Cl'), _chalk2.default.blue('Rule')]
        });
        for (var x = 0; x < warnings.length; x++) {
          console.log(warnings[x]);

          var reference = _chalk2.default.bold.cyan(warnings[x].line + ':' + warnings[x].column);
          var violation = _chalk2.default.yellow(warnings[x].text);

          table.push([reference, violation]);
        }
        process.stdout.write(errorTemp(r[i].source) + '\n');
        process.stdout.write(table.toString() + '\n');
      }
    } else {
      var noErr = (0, _boxen2.default)(_chalk2.default.cyan.bold('Your code doesn\'t contain any linting violations!'), {
        padding: 1,
        borderStyle: 'classic'
      });

      process.stdout.write(noErr + '\n');
    }
  }).catch(function (err) {
    console.warn(err);
  });
};

var cli = (0, _meow2.default)('\n    Usage\n      $ wilco <input>\n\n    Examples\n      $ wilco ./styles/**/*.css\n');

wilco(cli.input[0]);
